// -*- C++;indent-tabs-mode: t; tab-width: 4; c-basic-offset: 4; -*-
/*
 * get_resolution.cpp
 *
 * Note that this testcase fails if not run as root
 *
 *  Test suite program for C++ bindings
 */

#include <iostream>
#include <iomanip>
#include <usbpp.h>

#define VENDOR_LOGITECH 0x046D

using namespace std;

int main(void)
{

	USB::Busses buslist;
	USB::Device *device;
	QPtrList<USB::Device> miceFound;

	QByteArray resolution;

	resolution.resize(1); // we need a single byte for this.
	resolution.fill('Z'); // check figure

	cout << "idVendor/idProduct/bcdDevice" << endl;

	USB::DeviceIDList mouseList;

	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC00E)); // Wheel Mouse Optical
	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC012)); // MouseMan Dual Optical
	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC00F)); // MouseMan Traveler
	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC024)); // MX300 optical 
	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC025)); // MX500 optical 
	mouseList.append(USB::DeviceID(VENDOR_LOGITECH, 0xC031)); // iFeel Mouse (silver)

	miceFound = buslist.match(mouseList);

	for ( device = miceFound.first(); device; device = miceFound.next() ) {
		cout << hex << setw(4) << setfill('0')
			 << device->idVendor() << "  /  "
			 << hex << setw(4) << setfill('0')
			 << device->idProduct() << "  /  "
			 << hex << setw(4) << setfill('0')
			 << device->idRevision() << "       "
			 << endl;

		if ( 0 > device->controlTransfer(USB_TYPE_VENDOR | USB_ENDPOINT_IN,
										 0x01,
										 0x000E,
										 0x0000,
										 0x0001,
										 resolution) ) {
			cout << "control transfer test failed: " << usb_strerror() << endl;
			return EXIT_FAILURE;
		}

		if (3 == resolution.data()[0]) {
			cout << "Resolution is 400cpi" << endl;
		} else if (4 == resolution.data()[0]) {
			cout << "Resolution is 800cpi" << endl;
		} else {
			cout << "Unexpected resolution result" << endl;
		}
	}

	return 0;
}
